@@ -1,32 +1,38 @@
-from typing import Literal
+"""Class for modifying SQL columns or primary keys."""
+from typing import Literal, List
+import pyodbc
 
-from mssql_dataframe.core import helpers
+from mssql_dataframe.core import dynamic
 
 
-class modify():
+class modify:
+    def __init__(self, connection: pyodbc.connect):
+        """Class for modifying SQL table columns.
 
-    def __init__(self, connection):
-        '''Class for modifying SQL table columns.
-        
         Parameters
         ----------
-        connection (mssql_dataframe.connect) : connection for executing statement
-        '''
+        connection (pyodbc.Connection) : connection for executing statement
+        """
 
-        self.__connection__ = connection
+        self._connection = connection
 
-
-    def column(self, table_name: str, modify: Literal['add','alter','drop'], column_name: str, data_type: str = None, not_null: bool = False):
+    def column(
+        self,
+        table_name: str,
+        modify: Literal["add", "alter", "drop"],
+        column_name: str,
+        data_type: str = None,
+        is_nullable: bool = True,
+    ) -> None:
         """Add, alter, or drop a column in an existing SQL table.
 
         Parameters
         ----------
-
         table_name (str) : name of table
         modify (str) : method of modification, see below for description of options
         column_name (str) : name of column
         data_type (str) : if modify='add' or modify='alter', data type and optionally size/precision
-        not_null (bool, default=False) : if modify='alter', specification for if the column is nullable
+        is_nullable (bool, default=True) : if modify='alter', specification for if the column is nullable
 
         modify = 'add' : adds the column to the table
         modify = 'alter' : change the data type or nullability of the column
@@ -39,25 +45,22 @@ class modify():
 
         Example
         -------
-        
-        #### add a column
 
+        #### add a column
         modify.column('SomeTable', modify='add', column_name='B', data_type='VARCHAR(20)')
 
         #### alter a column
-
-        modify.column('SomeTable', 'alter', 'Column1', data_type='TINYINT', not_null=True)
+        modify.column('SomeTable', 'alter', 'Column1', data_type='TINYINT', is_nullable=False)
 
         #### drop a column
-
         modify.column('SomeTable', modify='drop', column_name='B')
 
         """
 
-        options = ['add','alter','drop']
+        options = ["add", "alter", "drop"]
         if modify not in options:
-            raise ValueError("modify must be one of: "+str(options))
-        
+            raise ValueError("modify must be one of: " + str(options))
+
         statement = """
             DECLARE @SQLStatement AS NVARCHAR(MAX);
             DECLARE @TableName SYSNAME = ?;
@@ -65,18 +68,18 @@ class modify():
             {declare_type}
             {declare_size}
 
-            SET @SQLStatement = 
+            SET @SQLStatement =
                 N'ALTER TABLE '+QUOTENAME(@TableName)+
                 {syntax} +QUOTENAME(@ColumnName) {type_column} {size_column} {null_column}+';'
 
-            EXEC sp_executesql 
+            EXEC sp_executesql
                 @SQLStatement,
                 N'@TableName SYSNAME, @ColumnName SYSNAME {parameter_type} {parameter_size}',
                 @TableName=@TableName, @ColumnName=@ColumnName {value_type} {value_size};
         """
 
         args = [table_name, column_name]
-        if modify=='drop':
+        if modify == "drop":
             syntax = "'DROP COLUMN'"
             declare_type = ""
             declare_size = ""
@@ -87,16 +90,16 @@ class modify():
             parameter_size = ""
             value_type = ""
             value_size = ""
-        elif modify=='add' or modify=='alter':
-            if modify=='add':
+        elif modify == "add" or modify == "alter":
+            if modify == "add":
                 syntax = "'ADD'"
-            elif modify=='alter':
+            elif modify == "alter":
                 syntax = "'ALTER COLUMN'"
             declare_type = "DECLARE @ColumnType SYSNAME = ?;"
             type_column = "+' '+QUOTENAME(@ColumnType)"
             parameter_type = ", @ColumnType SYSNAME"
             value_type = ", @ColumnType=@ColumnType"
-            size, dtypes_sql = helpers.column_spec(data_type)
+            size, dtypes_sql = dynamic.column_spec(data_type)
             if size is None:
                 declare_size = ""
                 size_column = ""
@@ -107,32 +110,41 @@ class modify():
                 size_column = "+' '+@ColumnSize"
                 parameter_size = ", @ColumnSize VARCHAR(MAX)"
                 value_size = ", @ColumnSize=@ColumnSize"
-            if not_null:
-                null_column = "+' NOT NULL'"
-            else:
+            if is_nullable:
                 null_column = ""
-            
+            else:
+                null_column = "+' NOT NULL'"
+
             args += [dtypes_sql, size]
 
         statement = statement.format(
-            declare_type=declare_type, declare_size=declare_size,
-            syntax=syntax, 
-            type_column=type_column, size_column=size_column, null_column=null_column,
-            parameter_type=parameter_type, parameter_size=parameter_size,
-            value_type=value_type, value_size=value_size
+            declare_type=declare_type,
+            declare_size=declare_size,
+            syntax=syntax,
+            type_column=type_column,
+            size_column=size_column,
+            null_column=null_column,
+            parameter_type=parameter_type,
+            parameter_size=parameter_size,
+            value_type=value_type,
+            value_size=value_size,
         )
 
         args = [x for x in args if x is not None]
-        helpers.execute(self.__connection__, statement, args)
-        self.__connection__.cursor.commit()
+        cursor = self._connection.cursor()
+        cursor.execute(statement, *args)
 
-
-    def primary_key(self, table_name: str, modify: Literal['add','drop'], columns: list, primary_key_name: str):
-        '''Add or drop the primary key from a table.
+    def primary_key(
+        self,
+        table_name: str,
+        modify: Literal["add", "drop"],
+        columns: List[str],
+        primary_key_name: str,
+    ) -> None:
+        """Add or drop the primary key from a table.
 
         Parameters
         ----------
-
         table_name (str) : name of the table to add/drop the primary key
         key_name (str) : name of the primary key to add/drop
         columns (list|str) : name of the column(s) to add/drop as the primary key
@@ -148,20 +160,18 @@ class modify():
         --------
 
         #### add a primary key
-
         modify.primary_key('SomeTable', modify='add', columns='A', primary_key_name = '_pk_1')
 
         #### drop a primary key
-
         sql.modify.primary_key('SomeTable', modify='drop', columns='A',  primary_key_name = '_pk_1')
 
-        '''
+        """
 
-        options = ['add','drop']
+        options = ["add", "drop"]
         if modify not in options:
-            raise ValueError("modify must be one of: "+str(options))
+            raise ValueError("modify must be one of: " + str(options))
 
-        if isinstance(columns,str):
+        if isinstance(columns, str):
             columns = [columns]
 
         statement = """
@@ -170,34 +180,47 @@ class modify():
             DECLARE @PrimaryKeyName SYSNAME = ?;
             {declare}
 
-            SET @SQLStatement = 
+            SET @SQLStatement =
                 N'ALTER TABLE '+QUOTENAME(@TableName)+
                 {syntax} + QUOTENAME(@PrimaryKeyName) {keys} +';'
-            EXEC sp_executesql 
+            EXEC sp_executesql
                 @SQLStatement,
                 N'@TableName SYSNAME, @PrimaryKeyName SYSNAME {parameter}',
                 @TableName=@TableName, @PrimaryKeyName=@PrimaryKeyName {value};
         """
 
         args = [table_name, primary_key_name]
-        if modify=='add':
+        if modify == "add":
             args += columns
-            declare = "\n".join(["DECLARE @PK"+str(idx)+" SYSNAME = ?;" for idx,_ in enumerate(columns)])
+            declare = "\n".join(
+                [
+                    "DECLARE @PK" + str(idx) + " SYSNAME = ?;"
+                    for idx, _ in enumerate(columns)
+                ]
+            )
             syntax = "'ADD CONSTRAINT '"
-            keys = "+','+".join(["QUOTENAME(@PK"+str(idx)+")" for idx,_ in enumerate(columns)])
-            keys = "+'PRIMARY KEY ('+"+keys+"+')'"
-            parameter = " ".join([", @PK"+str(idx)+" SYSNAME" for idx,_ in enumerate(columns)])
-            value = " ".join([", @PK"+str(idx)+"=@PK"+str(idx) for idx,_ in enumerate(columns)])
-        elif modify=='drop':
+            keys = "+','+".join(
+                ["QUOTENAME(@PK" + str(idx) + ")" for idx, _ in enumerate(columns)]
+            )
+            keys = "+'PRIMARY KEY ('+" + keys + "+')'"
+            parameter = " ".join(
+                [", @PK" + str(idx) + " SYSNAME" for idx, _ in enumerate(columns)]
+            )
+            value = " ".join(
+                [
+                    ", @PK" + str(idx) + "=@PK" + str(idx)
+                    for idx, _ in enumerate(columns)
+                ]
+            )
+        elif modify == "drop":
             declare = ""
             syntax = "'DROP CONSTRAINT '"
             keys = ""
             parameter = ""
             value = ""
-        statement = statement.format(declare=declare, 
-            syntax=syntax, keys=keys, 
-            parameter=parameter, value=value
+        statement = statement.format(
+            declare=declare, syntax=syntax, keys=keys, parameter=parameter, value=value
         )
 
-        helpers.execute(self.__connection__, statement, args)
-        self.__connection__.cursor.commit()
+        cursor = self._connection.cursor()
+        cursor.execute(statement, *args)
